#
# spec file for package python-congressclient
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-congressclient
Version:        2.0.1
Release:        bp155.2.11
Summary:        Client library for Congress
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/python-congressclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-congressclient/python-congressclient-2.0.1.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-fixtures
BuildRequires:  python3-mock
BuildRequires:  python3-osc-lib
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests-mock
BuildRequires:  python3-sphinxcontrib-apidoc
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
This package is client for Congress component.
Congress is an open policy framework for the cloud.
Congress fetches information about VMs from Nova,
and network state from Neutron, etc. Congress then
feeds input data from those services into its policy
engine where Congress verifies that the cloud's actual
state abides by the cloud operator's policies. Congress
is designed to work with any policy and any cloud service.

%package -n python3-congressclient
Summary:        Client library for OpenStack Congress
Group:          Development/Languages/Python
Requires:       python3-Babel >= 2.3.4
Requires:       python3-cliff >= 2.8.0
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-requests
Requires:       python3-six >= 1.10.0

%description -n python3-congressclient
Client library for interacting with Openstack Congress API.

%package doc
Summary:        Documentation for OpenStack Congress API client libary
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description doc
This package is client for Congress component.
Congress is an open policy framework for the cloud.
Congress fetches information about VMs from Nova,
and network state from Neutron, etc. Congress then
feeds input data from those services into its policy
engine where Congress verifies that the cloud's actual
state abides by the cloud operator's policies. Congress
is designed to work with any policy and any cloud service.
This package contains the documentation.

%prep
%autosetup -p1 -n python-congressclient-%{version}
%py_req_cleanup

%build
%{py3_build}

# Build HTML docs and man page
PBR_VERSION=2.0.1 %sphinx_build -b html doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{__python3} -m stestr.cli run

%files -n python3-congressclient
%doc README.rst
%license LICENSE
%{python3_sitelib}/congressclient
%{python3_sitelib}/*.egg-info

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.1
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update master for stable/train
  - Switch to Ussuri jobs
  - Generate PDF documentation
  - tox: Keeping going with docs
  - Change README.rst with a better title
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- build against python 3.x only
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.13.0
  - Switch python3 versions of test jobs to match Train PTI
  - add releasenotes tox env and commands
  - Cap sphinx for py2 to match global requirements
  - OpenDev Migration Patch
  - Dropping the py35 testing
  - add python 3.7 unit test job
  - Changes for url transition to OpenDev
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.12.0
  - Add Python 3.6 classifier to setup.cfg
  - Switch to stestr
  - Change openstack-dev to openstack-discuss
  - Update hacking version
  - Add python 3.6 for test in tox
  - switch documentation job to new PTI
  - add python 3.6 unit test job
  - Use template for lower-constraints
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.11.0
  - fix tox python3 overrides
  - Update links in README
  - Update the home-page
  - Adds support for z3 policies
  - Follow the new PTI for document build
  - Cleanup test-requirements
  - doc update to fix errors from new sphinx version 1.7.5
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 1.9.0
  - Enable include_rules option for library policy
  - Support activating library policy
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.8.0
  - Use oslo_log instead of system logging for consistency
  - Revert "Fix the problem of default width is small"
  - Remove unused packages from requirements.txt
  - Add client methods for library policy CRUD
  - Remove log translations
  - Update .gitignore
  - Python 3.5 is added
  - Use 'project' instead of 'tenant' when switching to openstackclient command
  - Fix modindex link
  - Set default max-width to 80 everywhere
  - [Fix gate]Update test requirement
  - Added how to install from a branch
  - Add command to create policy from file
  - remove redundant path variables in v1/client.py
  - Update documentation link
  - Update the documentation link for doc migration
  - Updated from global requirements
  - Fix the problem of default width is small
  - Switch from oslosphinx to openstackdocstheme
  - doc migration
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.6.0:
  - Add plug-in summary for osc doc
  - Add Constraints support
  - Remove unnecessary utf coding
  - Add method to show datasource
  - Show team and repo badges on README
  - Fall back to UUID when delete by name fails
  - Remove unnecessary db calls to list_datasources
  - Minor edit of misleading message
  - no longer use oslo-incubator code
  - Updated from global requirements
  - Change home-page and documentation link
  - Remove oslo.i18n from requirements
* Thu Sep  8 2016 tbechtold@suse.com
  update to version 1.5.0
  * Remove discover from test-requirements
  * Remove python-keystoneclient dependency
  * Add __ne__ built-in function
  * Add missing makefile so HTML docs can be generated
  * Add release notes
  * Updated from global requirements
  * Support push rows to datasources
* Fri Aug 26 2016 tbechtold@suse.com
- Initial packaging (version 1.4.0)
